import { REFER } from "@/components/popover-select/api";
import { SAVE, ITEM, REMOVE, SUBMIT } from "@/api/business/purchase/apply";

export default function useMethods() {
  const fetchItem = async ({ _this, prop }) => {
    try {
      // try
      _this.loading = true;
      const { code, data } = await ITEM(prop);
      if (code === 200) {
        _this.params = data;
      }
    } catch (err) {
      // catch
      console.error(err);
    } finally {
      // finally
      _this.loading = false;
    }
  };
  const fetchRefer = async ({ _this, prop, type, source }) => {
    const { rateCode } = prop;
    if (type === "MATERIAL_PARAM") {
      try {
        // try
        _this.loading = true;
        const { code, rows } = await REFER({
          search: rateCode,
          type: "TAX_RATE_PARAM",
        });
        if (code === 200) {
          const [{ ntaxrate }] = rows;
          source.tax = ntaxrate === "0E-8" ? "0.00000000" : ntaxrate;
        }
      } catch (err) {
        // catch
        console.error(err);
      } finally {
        // finally
        _this.loading = false;
      }
    }
  };
  const open = ({ _this }) => {
    _this.visible = true;
    _this.tabName = _this.tabColumns[0].key;
  };
  const hide = ({ _this }) => {
    _this.visible = false;
  };
  const add = ({ _this, prop }) => {
    _this.$refs[prop].validate(async (valid) => {
      if (valid) {
        try {
          // try
          const {
            priceApplyOrgs: _priceApplyOrgs,
            priceApplyItems: _priceApplyItems,
          } = _this.params;
          const id = undefined;
          const priceApplyOrgs = _priceApplyOrgs.map((item) => ({
            ...item,
            id: undefined,
            applyId: undefined,
          }));
          const priceApplyItems = _priceApplyItems.map((item) => ({
            ...item,
            id: undefined,
            applyId: undefined,
          }));
          const { msg, code } = await SAVE({
            ..._this.params,
            id,
            priceApplyOrgs,
            priceApplyItems,
          });
          if (code === 200) {
            _this.hide();
            _this.$emit("success");
            _this.$notify.success(msg);
          }
        } catch (err) {
          // catch
          console.error(err);
        } finally {
          // finally
          _this.loading = false;
        }
      } else {
        return false;
      }
    });
  };
  const edit = ({ _this, prop }) => {
    _this.$refs[prop].validate(async (valid) => {
      if (valid) {
        try {
          // try
          const { msg, code } = await SAVE({
            ..._this.params,
          });
          if (code === 200) {
            _this.hide();
            _this.$emit("success");
            _this.$notify.success(msg);
          }
        } catch (err) {
          // catch
          console.error(err);
        } finally {
          // finally
          _this.loading = false;
        }
      } else {
        return false;
      }
    });
  };
  const remove = async ({ _this, prop }) => {
    try {
      // try
      const { msg, code } = await REMOVE(prop);
      if (code === 200) {
        _this.$emit("success");
        _this.$notify.success(msg);
      }
    } catch (err) {
      // catch
      console.error(err);
    } finally {
      // finally
    }
  };
  const submit = async ({ _this, prop }) => {
    try {
      // try
      const ids = prop.map((item) => item.id).join(",");
      const { msg, code } = await SUBMIT(ids);
      if (code === 200) {
        _this.$emit("success");
        _this.$notify.success(msg);
      }
    } catch (err) {
      // catch
      console.error(err);
    } finally {
      // finally
    }
  };
  return {
    open,
    hide,
    add,
    edit,
    remove,
    submit,
    fetchItem,
    fetchRefer,
  };
}
